@@ -29,20 +29,20 @@ _pkg_config = {
     'android_abi':        '',
     'arch':               '',
     'default_bin_dir':    '/usr/bin',
-    'default_mod_dir':    '/usr/lib/python3.11/site-packages',
+    'default_mod_dir':    '/usr/lib/python3.12/site-packages',
     'default_sip_dir':    '/usr/share/sip',
     'deployment_target':  '',
     'platform':           'linux-g++',
-    'py_conf_inc_dir':    '/usr/include/python3.11',
-    'py_inc_dir':         '/usr/include/python3.11',
-    'py_lib_dir':         '/usr/lib/python3.11/config',
-    'py_version':         0x030b08,
+    'py_conf_inc_dir':    '/usr/include/python3.12',
+    'py_inc_dir':         '/usr/include/python3.12',
+    'py_lib_dir':         '/usr/lib/python3.12/config',
+    'py_version':         0x030c07,
     'qt_framework':       0,
     'sip_bin':            '/usr/bin/sip',
-    'sip_config_args':    'CFLAGS=-march=armv8-a -O2 -pipe -fstack-protector-strong -fno-plt LFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now --no-dist-info',
-    'sip_inc_dir':        '/usr/include/python3.11',
-    'sip_module_dir':     '/usr/lib/python3.11/site-packages',
-    'sip_root_dir':       '/usr/lib/python3.11/site-packages',
+    'sip_config_args':    'CFLAGS=-march=armv8-a -O2 -pipe -fstack-protector-strong -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer LFLAGS=-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs --no-dist-info',
+    'sip_inc_dir':        '/usr/include/python3.12',
+    'sip_module_dir':     '/usr/lib/python3.12/site-packages',
+    'sip_root_dir':       '/usr/lib/python3.12/site-packages',
     'sip_version':        0x041319,
     'sip_version_str':    '4.19.25',
     'universal':          ''
@@ -52,7 +52,7 @@ _default_macros = {
     'AIX_SHLIB':                '',
     'AR':                       'ar cqs',
     'CC':                       'gcc',
-    'CFLAGS':                   '-march=armv8-a -O2 -pipe -fstack-protector-strong -fno-plt',
+    'CFLAGS':                   '-march=armv8-a -O2 -pipe -fstack-protector-strong -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer',
     'CFLAGS_APP':               '',
     'CFLAGS_CONSOLE':           '',
     'CFLAGS_DEBUG':             '-g',
@@ -101,7 +101,7 @@ _default_macros = {
     'INCDIR':                   '',
     'INCDIR_OPENGL':            '/usr/X11R6/include',
     'INCDIR_X11':               '/usr/X11R6/include',
-    'LFLAGS':                   '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+    'LFLAGS':                   '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs',
     'LFLAGS_CONSOLE':           '',
     'LFLAGS_CONSOLE_DLL':       '',
     'LFLAGS_DEBUG':             '',
